#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-discover
version:              2.11.4
visibility:           public
id:                   hspec-discover-2.11.4-EFsQaLm8n6c5e9UFZiGUFP
key:                  hspec-discover-2.11.4-EFsQaLm8n6c5e9UFZiGUFP
license:              MIT
copyright:            (c) 2012-2023 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests

    <https://hspec.github.io/hspec-discover.html>

category:             Testing
abi:                  1ddb60b8a7246907aabc35c831f2c025
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort

hidden-modules:       Paths_hspec_discover
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-discover-2.11.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-discover-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-discover-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-discover
hs-libraries:         HShspec-discover-2.11.4-EFsQaLm8n6c5e9UFZiGUFP
depends:              base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1
haddock-interfaces:
    /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock

haddock-html:         /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

